import '../css/style.scss';

const linguiseFrontendScript = () => {
    var config = linguise_configs.vars.configs;
    var languages_keys = Object.keys(config.languages);
    config.scheme = window.location.protocol;
    config.host = window.location.host;
    config.query = window.location.search;
    config.current_language = config.default_language;

    if ((config.base ? config.base : '') + config.original_path !== window.location.pathname) {
        // Retrieve current language from url
        var regex = new RegExp('^' + (config.base !== '' ? config.base : '') + '/(' + languages_keys.join('|') + ')(?:/(.*)|$)');
        var result = regex.exec(window.location.pathname);

        if (result !== null && result.length >= 2 && result[1]) {
            config.current_language = result[1];
        }
    }

    if (document.querySelectorAll('.linguise_parent_menu_item').length) {
        document.querySelectorAll('.linguise_parent_menu_item a').forEach(e => {
            var lang_label = '';

            if (parseInt(config.enable_flag) === 1) {
                lang_label += `<span class="linguise_flags linguise_flag_${config.current_language} linguise_language_icon"></span>`;
            }

            if (parseInt(config.enable_language_name) === 1) {
                lang_label += `<span class="linguise_lang_name">${config.languages[config.current_language]}</span>`;
            }

            e.innerHTML = lang_label;
        });
    }

    var linguise_switcher = document.querySelectorAll('.linguise_switcher');
    if (linguise_switcher.length) {
        linguise_switcher.forEach(e => {
            if (!e.classList.contains('linguise_parent_menu_item')) {
                var switcher = '';
                switch (config.flag_display_type) {
                    case 'popup':
                        if (parseInt(config.enable_flag) === 1) {
                            switcher += `<span class="linguise_flags linguise_flag_${config.current_language} linguise_language_icon"></span>`;
                        }

                        if (parseInt(config.enable_language_name) === 1) {
                            switcher += `<span class="linguise_lang_name">${config.languages[config.current_language]}</span>`;
                        }

                        switcher += `<span class="lccaret">▼</span>`;
                        document.querySelectorAll('.linguise_switcher_popup').forEach(e => {
                            e.innerHTML = switcher;
                        });
                        break;

                    case 'side_by_side':
                        for (var ij = 0; ij < languages_keys.length; ij++) {
                            switcher += `<li ${languages_keys[ij] === config.current_language ? 'class="linguise_current"' : ''}>`;

                            if (languages_keys[ij] !== config.current_language) {
                                switcher += `<a  href="${config.scheme}//${config.host + (config.base ? config.base : '') + (languages_keys[ij] === config.default_language ? '' : '/' + languages_keys[ij]) + config.original_path + config.trailing_slashes + (config.query ? config.query : '')}">`;
                            }

                            if (parseInt(config.enable_flag) === 1) {
                                switcher += `<span class="linguise_flags linguise_flag_${languages_keys[ij]} linguise_language_icon"></span>`;
                            }

                            if (parseInt(config.enable_language_name) === 1) {
                                switcher += `<span class="linguise_lang_name">${config.languages[languages_keys[ij]]}</span>`;
                            }

                            if (languages_keys[ij] !== config.current_language) {
                                switcher += `</a>`;
                            }

                            switcher += `</li>`;
                        }
                        document.querySelectorAll('.linguise_switcher_side_by_side').forEach(e => {
                            e.innerHTML = switcher;
                        });
                        break;

                    case 'dropdown':
                        switcher += `<li class="linguise_current">`;
                        if (parseInt(config.enable_flag) === 1) {
                            switcher += `<span class="linguise_flags linguise_flag_${config.current_language} linguise_language_icon"></span>`;
                        }

                        if (parseInt(config.enable_language_name) === 1) {
                            switcher += `<span class="linguise_lang_name">${config.languages[config.current_language]}</span>`;
                        }
                        switcher += `<span class="lccaret">▼</span>`;
                        switcher += `<ul class="linguise_switcher_sub ${languages_keys.length > 9 ? 'many_languages' : ''}">`;
                        for (var ij = 0; ij < languages_keys.length; ij++) {
                            if (languages_keys[ij] !== config.current_language) {
                                switcher += `<li>`;
                                if (languages_keys[ij] !== config.current_language) {
                                    switcher += `<a  href="${config.scheme}//${config.host + (config.base ? config.base : '') + (languages_keys[ij] === config.default_language ? '' : '/' + languages_keys[ij]) + config.original_path + config.trailing_slashes + (config.query ? config.query : '')}">`;
                                }
                                if (parseInt(config.enable_flag) === 1) {
                                    switcher += `<span class="linguise_flags linguise_flag_${languages_keys[ij]} linguise_language_icon"></span>`;
                                }

                                if (parseInt(config.enable_language_name) === 1) {
                                    switcher += `<span class="linguise_lang_name">${config.languages[languages_keys[ij]]}</span>`;
                                }
                                if (languages_keys[ij] !== config.current_language) {
                                    switcher += `</a>`;
                                }
                                switcher += `</li>`;
                            }
                        }

                        switcher += '</ul>';
                        switcher += `</li>`;
                        document.querySelectorAll('.linguise_switcher_dropdown').forEach(e => {
                            e.innerHTML = switcher;
                        });
                        break;

                    default:
                        if (parseInt(config.enable_flag) === 1) {
                            switcher += `<span class="linguise_flags linguise_flag_${config.current_language} linguise_language_icon"></span>`;
                        }

                        if (parseInt(config.enable_language_name) === 1) {
                            switcher += `<span class="linguise_lang_name">${config.languages[config.current_language]}</span>`;
                        }

                        switcher += `<span class="lccaret">▼</span>`;
                        document.querySelectorAll('.linguise_switcher_popup').forEach(e => {
                            e.innerHTML = switcher;
                        });
                }

                if (config.display_position === 'top_left_no_scroll' || config.display_position === 'top_right_no_scroll' || config.display_position === 'bottom_left_no_scroll' || config.display_position === 'bottom_right_no_scroll') {
                    document.querySelector('body').appendChild(e);
                }
            } else {
                switch (config.flag_display_type) {
                    case 'dropdown':
                        var sub_switcher = `<ul class="linguise_switcher_sub ${languages_keys.length > 9 ? 'many_languages' : ''}">`;
                        for (var ij = 0; ij < languages_keys.length; ij++) {
                            if (languages_keys[ij] !== config.current_language) {
                                sub_switcher += `<li>`;
                                if (languages_keys[ij] !== config.current_language) {
                                    sub_switcher += `<a  href="${config.scheme}//${config.host + (config.base ? config.base : '') + (languages_keys[ij] === config.default_language ? '' : '/' + languages_keys[ij]) + config.original_path + config.trailing_slashes + (config.query ? config.query : '')}">`;
                                }
                                if (parseInt(config.enable_flag) === 1) {
                                    sub_switcher += `<span class="linguise_flags linguise_flag_${languages_keys[ij]} linguise_language_icon"></span>`;
                                }

                                if (parseInt(config.enable_language_name) === 1) {
                                    sub_switcher += `<span class="linguise_lang_name">${config.languages[languages_keys[ij]]}</span>`;
                                }
                                if (languages_keys[ij] !== config.current_language) {
                                    sub_switcher += `</a>`;
                                }
                                sub_switcher += `</li>`;
                            }
                        }

                        sub_switcher += '</ul>';

                        var div = document.createElement('div');
                        div.innerHTML = sub_switcher.trim();
                        e.appendChild(div.firstChild);
                        break;

                    case 'side_by_side':
                        var sub_switcher = '<div class="side_by_side_lang_list">';

                        sub_switcher += `<a  href="${config.scheme}//${config.host + (config.base ? config.base : '') + (config.current_language === config.default_language ? '' : '/' + config.current_language) + config.original_path + config.trailing_slashes + (config.query ? config.query : '')}">`;
                        if (parseInt(config.enable_flag) === 1) {
                            sub_switcher += `<span class="linguise_flags linguise_flag_${config.current_language} linguise_language_icon"></span>`;
                        }

                        if (parseInt(config.enable_language_name) === 1) {
                            sub_switcher += `<span class="linguise_lang_name">${config.languages[config.current_language]}</span>`;
                        }
                        sub_switcher += `</a>`;

                        for (var ij = 0; ij < languages_keys.length; ij++) {
                            if (languages_keys[ij] !== config.current_language) {
                                sub_switcher += `<a  href="${config.scheme}//${config.host + (config.base ? config.base : '') + (languages_keys[ij] === config.default_language ? '' : '/' + languages_keys[ij]) + config.original_path + config.trailing_slashes + (config.query ? config.query : '')}">`;
                                if (parseInt(config.enable_flag) === 1) {
                                    sub_switcher += `<span class="linguise_flags linguise_flag_${languages_keys[ij]} linguise_language_icon"></span>`;
                                }

                                if (parseInt(config.enable_language_name) === 1) {
                                    sub_switcher += `<span class="linguise_lang_name">${config.languages[languages_keys[ij]]}</span>`;
                                }
                                sub_switcher += `</a>`;
                            }
                        }
                        sub_switcher += '</div>';
                        var div = document.createElement('div');
                        div.innerHTML = sub_switcher;
                        e.appendChild(div.firstChild);
                        break;

                    case 'popup':
                        if (document.querySelectorAll('.linguise_parent_menu_item').length) {
                            e.addEventListener("click", function(){
                                window.openLanguagePopUp();
                            });
                        }
                        break;
                }
            }
        })
    }

    window.openLanguagePopUp = function (e) {
        if (e !== undefined && e.prevenDefault) {
            e.preventDefault();
        }

        if (window.language_popup_initialised === true) {
            document.querySelector('#linguise_background').style.display = 'block';
            document.querySelector('#linguise_popup').style.display = 'block';
            return;
        }

        window.language_popup_initialised = true;
        var script = `<div id="linguise_background"></div><div id="linguise_popup" class="${((config['flag_shape'] === 'rounded') ? 'linguise_flag_rounded' : 'linguise_flag_rectangular')}"><a class="close" href="#"><span></span></a>`;

        if (config.pre_text) {
            script += `<p>${config.pre_text}</p>`;
        }

        script += `<ul translate="no">`;

        for (var ij = 0; ij < languages_keys.length; ij++) {
            script += `<li ${languages_keys[ij] === config.current_language ? 'class="linguise_current"' : ''}>`;

            if (languages_keys[ij] !== config.current_language) {
                script += `<a  href="${config.scheme}//${config.host + (config.base ? config.base : '') + (languages_keys[ij] === config.default_language ? '' : '/' + languages_keys[ij]) + config.original_path + config.trailing_slashes + (config.query ? config.query : '')}">`;
            }

            script += `<span class="linguise_flags linguise_flag_${languages_keys[ij]}"></span>`;
            script += `<span class="linguise_lang_name">${config.languages[languages_keys[ij]]}</span>`;

            if (languages_keys[ij] !== config.current_language) {
                script += `</a>`;
            }

            script += `</li>`;
        }

        script += `</ul>`;

        if (config.post_text) {
            script += `<p>${config.post_text}</p>`;
        }

        script += `</div>`;
        document.querySelector('body').innerHTML += script;
        document.querySelector('#linguise_background').onclick = function (e) {
            e.preventDefault();
            document.querySelector('#linguise_background').style.display = 'none';
            document.querySelector('#linguise_popup').style.display = 'none';
        };

        document.querySelector('#linguise_popup .close').onclick = function (e) {
            e.preventDefault();
            document.querySelector('#linguise_background').style.display = 'none';
            document.querySelector('#linguise_popup').style.display = 'none';
        };

        if (document.querySelector('.linguise_parent_menu_item') !== null) {
            document.querySelectorAll('.linguise_parent_menu_item').forEach(e => {
                e.addEventListener("click", function(){
                    window.openLanguagePopUp();
                });
            });
        }
    };
};

if( document.readyState !== 'loading' ) {
    linguiseFrontendScript();
} else {
    document.addEventListener('DOMContentLoaded', function () {
        linguiseFrontendScript();
    });
}