<?php
/**
 * Plugin Name: Linguise
 * Plugin URI: https://www.linguise.com/
 * Description: Linguise translation plugin
 * Version: 1.5.0
 * Text Domain: linguise
 * Domain Path: /languages
 * Author: Linguise
 * Author URI: https://www.linguise.com/wordpress
 * License: GPL2
 */

defined('ABSPATH') || die('');

define('LINGUISE_VERSION', '1.4.1');
define('LINGUISE_PLUGIN_URL', plugin_dir_url(__FILE__));
define('LINGUISE_PLUGIN_PATH', plugin_dir_path(__FILE__));

register_activation_hook(__FILE__, function () {
    if (!get_option('linguise_install_time', false)) {
        add_option('linguise_install_time', time());
    }
});

include_once(__DIR__ . DIRECTORY_SEPARATOR . 'src' . DIRECTORY_SEPARATOR . 'install.php');

/**
 * Get options
 *
 * @return array|mixed|void
 */
function linguiseGetOptions()
{
    $defaults = array(
        'token' => '',
        'default_language' => 'en',
        'enabled_languages' => array(),
        'flag_display_type' => 'popup',
        'display_position' => 'no',
        'enable_flag' => 1,
        'enable_language_name' => 1,
        'flag_shape' => 'rounded',
        'flag_border_radius' => 0,
        'flag_width' => 24,
        'browser_redirect' => 0,
        'language_name_display' => 'en',
        'pre_text' => '',
        'post_text' => '',
        'alternate_link' => 1,
        'custom_css' => '',
        'cache_enabled' => 1,
        'cache_max_size' => 200,
        'language_name_color' => '#222',
        'language_name_hover_color' => '#222',
        'flag_shadow_h' => 3,
        'flag_shadow_v' => 3,
        'flag_shadow_blur' => 6,
        'flag_shadow_spread' => 0,
        'flag_shadow_color' => '#bfbfbf',
        'flag_hover_shadow_h' => 3,
        'flag_hover_shadow_v' => 3,
        'flag_hover_shadow_blur' => 6,
        'flag_hover_shadow_spread' => 0,
        'flag_hover_shadow_color' => '#bfbfbf'

    );
    $options = get_option('linguise_options');
    if (!empty($options) && is_array($options)) {
        $options = array_merge($defaults, $options);
    } else {
        $options = $defaults;
    }
    return $options;
}

if (wp_doing_ajax()) {
    return;
}

$languages_content = file_get_contents(dirname(__FILE__) . '/assets/languages.json');
$languages_names = json_decode($languages_content);

include_once(__DIR__ . DIRECTORY_SEPARATOR . 'src' . DIRECTORY_SEPARATOR . 'install.php');
include_once(__DIR__ . DIRECTORY_SEPARATOR . 'src' . DIRECTORY_SEPARATOR . 'switcher.php');
include_once(__DIR__ . DIRECTORY_SEPARATOR . 'src' . DIRECTORY_SEPARATOR . 'frontend/browser_language.php');

include_once(__DIR__ . DIRECTORY_SEPARATOR . 'src' . DIRECTORY_SEPARATOR . 'configuration.php');
include_once(__DIR__ . DIRECTORY_SEPARATOR . 'src' . DIRECTORY_SEPARATOR . 'admin/menu.php');

register_deactivation_hook(__FILE__, 'linguiseUnInstall');
/**
 * UnInstall plugin
 *
 * @return void
 */
function linguiseUnInstall()
{
    global $wp_filesystem;
    if (empty($wp_filesystem)) {
        require_once(ABSPATH . 'wp-admin/includes/file.php');
        WP_Filesystem();
    }

    // Save htaccess content
    $htaccess_path = ABSPATH . DIRECTORY_SEPARATOR . '.htaccess';
    $htaccess_content = $wp_filesystem->get_contents($htaccess_path);
    if ($wp_filesystem->exists($htaccess_path) && is_writable($htaccess_path)) {
        if (strpos($htaccess_content, '#### LINGUISE DO NOT EDIT ####') !== false) {
            $htaccess_content = preg_replace('/#### LINGUISE DO NOT EDIT ####.*?#### LINGUISE DO NOT EDIT END ####/s', '', $htaccess_content);
            $wp_filesystem->put_contents($htaccess_path, $htaccess_content);
        }
    }
}

add_action('admin_notices', function () {
    $translate_plugins = array(
        'sitepress-multilingual-cms/sitepress.php' => 'WPML Multilingual CMS',
        'polylang/polylang.php' => 'Polylang',
        'polylang-pro/polylang.php' => 'Polylang Pro',
        'translatepress-multilingual/index.php' => 'TranslatePress',
        'weglot/weglot.php' => 'Weglot',
        'gtranslate/gtranslate.php' => 'GTranslate',
        'conveythis-translate/index.php' => 'ConveyThis',
        'google-language-translator/google-language-translator.php' => 'Google Language Translator',
    );

    foreach ($translate_plugins as $path => $plugin_name) {
        if (is_plugin_active($path)) {
            echo '<div class="error">';
            echo '<p>'. sprintf(esc_html__('We\'ve detected that %s translation plugin is installed. Please disable it before using Linguise to avoid conflict with translated URLs mainly', 'linguise'), '<strong>'. esc_html($plugin_name) .'</strong>') .'</p>';
            echo '</div>';
        }
    }
});
