<?php
defined('ABSPATH') || die('');
?>
<div class="content">
    <ul>
        <li class="linguise-settings-option full-width transparent-option">
            <label for="token"
                   class="linguise-setting-label label-bolder normal-line-height linguise-tippy"
                   data-tippy="<?php esc_html_e('Register or login to your Linguise dashboard using the link here. Then copy the API key attached to the domain', 'linguise'); ?>"><?php esc_html_e('Linguise API key', 'linguise'); ?><span class="material-icons">help_outline</span></label>
            <p style="width: 100%;display: inline-block;margin: 10px 0;padding-left: 15px;"><?php echo sprintf(esc_html__('%s and copy your domain API key to activate the translation.', 'wpmf'), '<a href="https://dashboard.linguise.com/account/register" target="_blank">' . esc_html__('Register an account', 'linguise') . '</a>') ?></p>
            <div class="full-width">
                <input type="text" class="linguise-input custom-input" name="linguise_options[token]"
                       id="token"
                       value="<?php echo isset($options['token']) ? esc_html($options['token']) : '' ?>"/>
                <input type="submit"
                       class="linguise-button blue-button waves-effect waves-light small-radius small-button"
                       id="token_apply" value="<?php esc_html_e('Apply', 'linguise'); ?>"/>
            </div>
        </li>
        <li class="linguise-settings-option full-width">
            <label for="original_language"
                   class="linguise-setting-label label-bolder linguise-tippy"
                   data-tippy="<?php esc_html_e('Select the default language of your website. Make sure it\'s similar to your Linguise dashboard configuration', 'linguise'); ?>"><?php esc_html_e('Website original language', 'linguise'); ?><span class="material-icons">help_outline</span></label>
            <div class="items">
                <select id="original_language" name="linguise_options[default_language]"
                        class="linguise-select original-color">
                    <?php foreach ($languages_names as $language_code => $language) : ?>
                        <option value="<?php echo esc_attr($language_code); ?>" <?php echo isset($options['default_language']) ? (selected($options['default_language'], $language_code, false)) : (''); ?>>
                            <?php // phpcs:ignore WordPress.WP.I18n.NonSingularStringLiteralText -- don't need to translate this
                            esc_html_e($language['name']); ?> (<?php esc_html_e($language_code); ?>)
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>
        </li>
        <li class="linguise-settings-option full-width transparent-option">
            <label for="translate_into"
                   class="linguise-setting-label label-bolder linguise-tippy"
                   data-tippy="<?php esc_html_e('Select the languages you want to translate your website into. Make sure it\'s similar to your Linguise dashboard configuration', 'linguise'); ?>"><?php esc_html_e('Translate your website into', 'linguise'); ?><span class="material-icons">help_outline</span></label>
            <div class="items-blocks">
                <div class="block">
                    <select id="translate_into"
                            data-placeholder="<?php esc_html_e('Choose your language into', 'linguise'); ?>" multiple
                            class="chosen-select enabled_languages full-on-mobile chosen-sortable" name="linguise_options[enabled_languages][]">
                        <?php foreach ($languages_names as $language_code => $language) : ?>
                            <option value="<?php echo esc_attr($language_code); ?>" <?php echo isset($options['enabled_languages']) ? (selected(in_array($language_code, $options['enabled_languages']), true, false)) : (''); ?>>
                                <?php // phpcs:ignore WordPress.WP.I18n.NonSingularStringLiteralText -- don't need to translate this
                                esc_html_e($language['name']); ?> (<?php esc_html_e($language_code); ?>)
                            </option>
                        <?php endforeach; ?>
                    </select>
                    <input type="hidden" name="enabled_languages_sortable" class="enabled_languages_sortable">
                </div>
            </div>
            <p class="linguise_note"><?php echo sprintf(esc_html__('Note that adding or removing languages won\'t apply as the language configuration is made from the %s only.', 'linguise'), '<a target="_blank" href="https://dashboard.linguise.com/">'. esc_html__('Linguise dashboard', 'linguise') .'</a>'); ?></p>
            <p class="linguise_note"><?php esc_html_e('Please update the domain configuration from the dashboard and save the plugin settings again, thanks! :)', 'linguise') ?></p>
        </li>
        <li class="linguise-settings-option full-width transparent-option">
            <label class="linguise-setting-label label-bolder"><?php esc_html_e('How-to load the language switcher flags:', 'linguise'); ?></label>
            <div class="items-blocks language-switcher-as">
                <div class="block">
                    <div class="left-field">
                        <a class="linguise-button blue-button waves-effect waves-light small-radius"
                           data-tab="#wordpress_menu">
                            <?php esc_html_e('Wordpress menu', 'linguise'); ?>
                        </a>
                        <a class="linguise-button waves-effect waves-light small-radius" data-tab="#shortcode">
                            <?php esc_html_e('Shortcode', 'linguise'); ?>
                        </a>
                        <a class="linguise-button waves-effect waves-light small-radius" data-tab="#php_snippet">
                            <?php esc_html_e('PHP snippet', 'linguise'); ?>
                        </a>
                    </div>
                    <div class="right-field">
                        <div class="switcher-as-content" id="wordpress_menu">
                            <span><?php echo sprintf(esc_html__('OK it’s ready to use, navigate to the %s and insert the menu element named "Linguise flags". Note that to display a menu as a popup you need to select the inline position (see below)', 'linguise'), '<a target="__blank" href="' . esc_url(admin_url('nav-menus.php')) . '">menu system</a>'); ?></span>
                        </div>
                        <div class="switcher-as-content" id="shortcode">
                            <span><?php esc_html_e('Please copy the following shortcode anywhere in your WordPress content:', 'linguise'); ?> [linguise]</span>
                        </div>
                        <div class="switcher-as-content" id="php_snippet">
                            <span>echo do_shortcode('[linguise]');</span>
                        </div>
                    </div>
                </div>
                <div class="clearfix"></div>
            </div>
        </li>
        <li class="linguise-settings-option">
            <label for="id-alternate_link"
                   class="linguise-setting-label label-bolder linguise-label-inline"><?php esc_html_e('Insert alternate link tag', 'linguise'); ?></label>
            <div class="linguise-switch-button" style="float: left">
                <label class="switch">
                    <input type="hidden" name="linguise_options[alternate_link]" value="0">
                    <input type="checkbox" id="id-alternate_link" name="linguise_options[alternate_link]"
                           value="1" <?php echo isset($options['alternate_link']) ? (checked($options['alternate_link'], 1)) : (''); ?> />
                    <div class="slider"></div>
                </label>
            </div>

            <p class="description" style="width: 100%; display: inline-block; padding-left: 15px; margin: 2px 0 10px 0">
                <?php esc_html_e('It\'s highly recommended keeping this setting activated for SEO purpose', 'linguise'); ?>
            </p>
        </li>
        <li class="linguise-settings-option full-width">
            <label class="linguise-setting-label label-bolder linguise-tippy"
                   data-tippy="<?php esc_html_e('Display flag and/or language names. Language switcher default position could be anywhere in the content or in a fixed position that stays fixed or moves on scroll', 'linguise'); ?>"><?php esc_html_e('Language list display', 'linguise'); ?><span class="material-icons">help_outline</span></label>
            <div class="items-blocks language-list-display">
                <div class="display-type">
                    <ul>
                        <?php foreach (array('side_by_side' => esc_html__('Side By Side', 'linguise'), 'dropdown' => esc_html__('Dropdown', 'linguise'), 'popup' => esc_html__('Popup', 'linguise')) as $key => $value) : ?>
                            <li>
                                <input type="radio" class="flag_display_type" id="id-<?php echo esc_attr($key) ?>"
                                       name="linguise_options[flag_display_type]"
                                       value="<?php echo esc_attr($key) ?>" <?php checked($options['flag_display_type'], $key) ?>>
                                <label for="id-<?php echo esc_attr($key) ?>"><?php echo esc_html($value) ?></label>
                            </li>
                        <?php endforeach; ?>
                    </ul>
                    <div class="linguise_mt_20">
                        <?php esc_html_e('Position: '); ?>
                        <select name="linguise_options[display_position]" class="linguise-select full-on-mobile original-color">
                            <?php
                            $positions = array(
                                'no' => esc_html__('In place', 'linguise'),
                                'top_left' => esc_html__('Top left', 'linguise'),
                                'top_left_no_scroll' => esc_html__('Top left (no-scroll)', 'linguise'),
                                'top_right' => esc_html__('Top right', 'linguise'),
                                'top_right_no_scroll' => esc_html__('Top right (no-scroll)', 'linguise'),
                                'bottom_left' => esc_html__('Bottom left', 'linguise'),
                                'bottom_left_no_scroll' => esc_html__('Bottom left (no-scroll)', 'linguise'),
                                'bottom_right' => esc_html__('Bottom right', 'linguise'),
                                'bottom_right_no_scroll' => esc_html__('Bottom right (no-scroll)', 'linguise')
                            );
                            foreach ($positions as $key => $value) :
                                ?>
                                <option <?php selected($options['display_position'], $key) ?>
                                        value="<?php echo esc_attr($key) ?>">
                                    <?php echo esc_html($value) ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                </div>
                <div class="flag-name full-width">
                    <ul>
                        <li>
                            <div class="linguise-switch-button">
                                <label class="switch" style="margin: 2px  10px">
                                    <input type="hidden" name="linguise_options[enable_flag]" value="0">
                                    <input type="checkbox" id="id-enable_flag" name="linguise_options[enable_flag]"
                                           class="enable_flag"
                                           value="1" <?php echo isset($options['enable_flag']) ? (checked($options['enable_flag'], 1)) : (''); ?> />
                                    <div class="slider"></div>
                                </label>
                                <label for="id-enable_flag"><?php esc_html_e('Flag', 'linguise'); ?></label>
                            </div>
                        </li>

                        <li>
                            <div class="linguise-switch-button">
                                <label class="switch" style="margin: 2px  10px">
                                    <input type="hidden" name="linguise_options[enable_language_name]" value="0">
                                    <input type="checkbox" id="id-enable_language_name"
                                           name="linguise_options[enable_language_name]" class="enable_language_name"
                                           value="1" <?php echo isset($options['enable_language_name']) ? (checked($options['enable_language_name'], 1)) : (''); ?> />
                                    <div class="slider"></div>
                                </label>
                                <label for="id-language_name"><?php esc_html_e('Language Name', 'linguise'); ?></label>
                            </div>
                        </li>
                    </ul>
                </div>
            </div>
        </li>

        <li class="linguise-settings-option width-50-15">
            <label for="language_name_display" class="linguise-setting-label label-bolder linguise-tippy"
                   data-tippy="<?php esc_html_e('In the language switcher, display the language names in English or in the original language, i.e. French or Français', 'linguise'); ?>"><?php esc_html_e('Language names display', 'linguise'); ?><span class="material-icons">help_outline</span></label>
            <div class="items">
                <select name="linguise_options[language_name_display]"
                        class="linguise-select right-select original-color language_name_display">
                    <option value="en" <?php echo isset($options['language_name_display']) ? (selected($options['language_name_display'], 'en', false)) : (''); ?>><?php esc_html_e('English', 'linguise'); ?></option>
                    <option value="native" <?php echo isset($options['language_name_display']) ? (selected($options['language_name_display'], 'native', false)) : (''); ?>><?php esc_html_e('Native Language', 'linguise'); ?></option>
                </select>
            </div>
        </li>

        <li class="linguise-settings-option width-50-15 right-float">
            <label for="flag_shape" class="linguise-setting-label label-bolder linguise-label-inline linguise-tippy" data-tippy="<?php esc_html_e('Use round svg or rectangular svg flag icons', 'linguise'); ?>"><?php esc_html_e('Flag style', 'linguise'); ?><span class="material-icons">help_outline</span></label>
            <div class="items">
                <select name="linguise_options[flag_shape]"
                        class="linguise-select right-select original-color flag_shape">
                    <option value="rounded" <?php echo isset($options['flag_shape']) ? (selected($options['flag_shape'], 'rounded', false)) : (''); ?>><?php esc_html_e('Round', 'linguise'); ?></option>
                    <option value="rectangular" <?php echo isset($options['flag_shape']) ? (selected($options['flag_shape'], 'rectangular', false)) : (''); ?>><?php esc_html_e('Rectangular', 'linguise'); ?></option>
                </select>
            </div>
        </li>

        <li class="linguise-settings-option width-50-15">
            <label for="id-flag_border_radius"
                   class="linguise-setting-label label-bolder linguise-label-inline linguise-tippy" data-tippy="<?php esc_html_e('If you\'re using the rectangle flag shape you can apply a custom border radius in pixels', 'linguise'); ?>"><?php esc_html_e('Flag border radius (px)', 'linguise'); ?><span class="material-icons">help_outline</span></label>
            <input type="number" name="linguise_options[flag_border_radius]" class="flag_border_radius"
                   value="<?php echo (int)$options['flag_border_radius'] ?>" style="margin: 10px 15px; width: 100px; float: right">
        </li>

        <li class="linguise-settings-option width-50-15 right-float">
            <label for="id-flag_width"
                   class="linguise-setting-label label-bolder linguise-label-inline linguise-tippy" data-tippy="<?php esc_html_e('Select flags size in pixels. That doesn\'t change the image weight as it\'s a .svg format', 'linguise'); ?>"><?php esc_html_e('Flag size (px)', 'linguise'); ?><span class="material-icons">help_outline</span></label>
            <input type="number" name="linguise_options[flag_width]" class="flag_width"
                   value="<?php echo (int)$options['flag_width'] ?>" style="margin: 10px 15px; width: 100px; float: right">
        </li>

        <li class="linguise-settings-option width-50-15">
            <label for="language_name_color" class="linguise-setting-label label-bolder linguise-label-inline linguise-tippy" data-tippy="<?php esc_html_e('Select a default text color for your language names', 'linguise'); ?>"><?php esc_html_e('Language name color', 'linguise'); ?><span class="material-icons">help_outline</span></label>
            <div class="items">
                <input type="text" name="linguise_options[language_name_color]" value="<?php echo esc_attr($options['language_name_color']) ?>" class="language_name_color linguise-color-field" data-default-color="#222" />
            </div>
        </li>

        <li class="linguise-settings-option width-50-15 right-float">
            <label for="language_name_hover_color" class="linguise-setting-label label-bolder linguise-label-inline linguise-tippy" data-tippy="<?php esc_html_e('Select a mouse hover text color for your language names', 'linguise'); ?>"><?php esc_html_e('Language name hover color', 'linguise'); ?><span class="material-icons">help_outline</span></label>
            <div class="items">
                <input type="text" name="linguise_options[language_name_hover_color]" value="<?php echo esc_attr($options['language_name_hover_color']) ?>" class="language_name_hover_color linguise-color-field" data-default-color="#222" />
            </div>
        </li>

        <li class="linguise-settings-option width-50-15">
            <label for="language_name_color" class="linguise-setting-label label-bolder full-width linguise-tippy" data-tippy="<?php esc_html_e('Color and shadow size for your language flags', 'linguise'); ?>"><?php esc_html_e('Flag box shadow', 'linguise'); ?><span class="material-icons">help_outline</span></label>
            <div class="flag_shadow_element full-width">
                <p>
                    <label><?php esc_html_e('Shadow H offset (px)', 'linguise'); ?></label>
                    <input type="range" min="-50" max="50" value="<?php echo esc_attr($options['flag_shadow_h']) ?>" step="1" class="flag_shadow_h" onchange="window.linguiseUpdateTextInput(this.value, 'flag_shadow_h');">
                    <input type="number" id="flag_shadow_h" name="linguise_options[flag_shadow_h]" onchange="window.linguiseUpdateSliderInput(this.value, 'flag_shadow_h');" value="<?php echo esc_attr($options['flag_shadow_h']) ?>">
                </p>
                <p>
                    <label><?php esc_html_e('Shadow V offset (px)', 'linguise'); ?></label>
                    <input type="range" min="-50" max="50" value="<?php echo esc_attr($options['flag_shadow_v']) ?>" step="1" class="flag_shadow_v" onchange="window.linguiseUpdateTextInput(this.value, 'flag_shadow_v');">
                    <input type="number" id="flag_shadow_v" name="linguise_options[flag_shadow_v]" onchange="window.linguiseUpdateSliderInput(this.value, 'flag_shadow_v');" value="<?php echo esc_attr($options['flag_shadow_v']) ?>">
                </p>
                <p>
                    <label><?php esc_html_e('Shadow blur (px)', 'linguise'); ?></label>
                    <input type="range" min="0" max="50" value="<?php echo esc_attr($options['flag_shadow_blur']) ?>" step="1" class="flag_shadow_blur" onchange="window.linguiseUpdateTextInput(this.value, 'flag_shadow_blur');">
                    <input type="number" id="flag_shadow_blur" name="linguise_options[flag_shadow_blur]" onchange="window.linguiseUpdateSliderInput(this.value, 'flag_shadow_blur');" value="<?php echo esc_attr($options['flag_shadow_blur']) ?>">
                </p>
                <p>
                    <label><?php esc_html_e('Shadow spread (px)', 'linguise'); ?></label>
                    <input type="range" min="0" max="50" value="<?php echo esc_attr($options['flag_shadow_spread']) ?>" step="1" class="flag_shadow_spread" onchange="window.linguiseUpdateTextInput(this.value, 'flag_shadow_spread');">
                    <input type="number" id="flag_shadow_spread" name="linguise_options[flag_shadow_spread]" onchange="window.linguiseUpdateSliderInput(this.value, 'flag_shadow_spread');" value="<?php echo esc_attr($options['flag_shadow_spread']) ?>">
                </p>
                <p>
                    <label><?php esc_html_e('Shadow color', 'linguise'); ?></label>
                    <input type="text" name="linguise_options[flag_shadow_color]" value="<?php echo esc_attr($options['flag_shadow_color']) ?>" class="flag_shadow_color linguise-color-field" data-default-color="#bfbfbf" />
                </p>
            </div>
        </li>

        <li class="linguise-settings-option width-50-15 right-float">
            <label for="language_name_color" class="linguise-setting-label label-bolder full-width linguise-tippy" data-tippy="<?php esc_html_e('Color and shadow size for your language flags on mouse hover', 'linguise'); ?>"><?php esc_html_e('Flag box shadow on hover', 'linguise'); ?><span class="material-icons">help_outline</span></label>
            <div class="flag_shadow_element full-width">
                <p>
                    <label><?php esc_html_e('Shadow H offset (px)', 'linguise'); ?></label>
                    <input type="range" min="-50" max="50" value="<?php echo esc_attr($options['flag_hover_shadow_h']) ?>" step="1" class="flag_hover_shadow_h" onchange="window.linguiseUpdateTextInput(this.value, 'flag_hover_shadow_h');">
                    <input type="number" id="flag_hover_shadow_h" name="linguise_options[flag_hover_shadow_h]" onchange="window.linguiseUpdateSliderInput(this.value, 'flag_hover_shadow_h');" value="<?php echo esc_attr($options['flag_hover_shadow_h']) ?>">
                </p>
                <p>
                    <label><?php esc_html_e('Shadow V offset (px)', 'linguise'); ?></label>
                    <input type="range" min="-50" max="50" value="<?php echo esc_attr($options['flag_hover_shadow_v']) ?>" step="1" class="flag_hover_shadow_v" onchange="window.linguiseUpdateTextInput(this.value, 'flag_hover_shadow_v');">
                    <input type="number" id="flag_hover_shadow_v" name="linguise_options[flag_hover_shadow_v]" onchange="window.linguiseUpdateSliderInput(this.value, 'flag_hover_shadow_v');" value="<?php echo esc_attr($options['flag_hover_shadow_v']) ?>">
                </p>
                <p>
                    <label><?php esc_html_e('Shadow blur (px)', 'linguise'); ?></label>
                    <input type="range" min="0" max="50" value="<?php echo esc_attr($options['flag_hover_shadow_blur']) ?>" step="1" class="flag_hover_shadow_blur" onchange="window.linguiseUpdateTextInput(this.value, 'flag_hover_shadow_blur');">
                    <input type="number" id="flag_hover_shadow_blur" name="linguise_options[flag_hover_shadow_blur]" onchange="window.linguiseUpdateSliderInput(this.value, 'flag_hover_shadow_blur');" value="<?php echo esc_attr($options['flag_hover_shadow_blur']) ?>">
                </p>
                <p>
                    <label><?php esc_html_e('Shadow spread (px)', 'linguise'); ?></label>
                    <input type="range" min="0" max="50" value="<?php echo esc_attr($options['flag_hover_shadow_spread']) ?>" step="1" class="flag_hover_shadow_spread" onchange="window.linguiseUpdateTextInput(this.value, 'flag_hover_shadow_spread');">
                    <input type="number" id="flag_hover_shadow_spread" name="linguise_options[flag_hover_shadow_spread]" onchange="window.linguiseUpdateSliderInput(this.value, 'flag_hover_shadow_spread');" value="<?php echo esc_attr($options['flag_hover_shadow_spread']) ?>">
                </p>
                <p>
                    <label><?php esc_html_e('Shadow color', 'linguise'); ?></label>
                    <input type="text" name="linguise_options[flag_hover_shadow_color]" value="<?php echo esc_attr($options['flag_hover_shadow_color']) ?>" class="flag_hover_shadow_color linguise-color-field" data-default-color="#bfbfbf" />
                </p>
            </div>
        </li>
    </ul>
</div>