<?php
namespace Linguise\Script\Core;

defined('LINGUISE_SCRIPT_TRANSLATION') or die();

class Translation {

    /**
     * @var null|Translation
     */
    private static $_instance = null;

    /**
     * The editor token in cas we are in edition mode
     *
     * @var null|string
     */
    private $editor_token = null;

    /**
     * Retrieve singleton instance
     *
     * @return Translation|null
     */
    public static function getInstance() {

        if(is_null(self::$_instance)) {
            self::$_instance = new Translation();
        }

        return self::$_instance;
    }

    public function enableEditor($token) {;
        $this->editor_token = $token;
    }

    public function translate()
    {
        $response = Response::getInstance();

        if (!$response->getContent()) {
            return;
        }

        $boundary = new Boundary();
        $request =  \Linguise\Script\Core\Request::getInstance();

        $boundary->generatePostFields('version', Processor::$version);
        $boundary->generatePostFields('url', $request->getBaseUrl());
        $boundary->generatePostFields('language', $request->getLanguage());
        $boundary->generatePostFields('requested_path', $request->getPathname());
        $boundary->generatePostFields('content', $response->getContent());
        $boundary->generatePostFields('token',Configuration::getInstance()->get('token'));
        $boundary->generatePostFields('ip', Helper::getIpAddress());
        $boundary->generatePostFields('response_code', $response->getResponseCode());
        $boundary->generatePostFields('user_agent', !empty($_SERVER['HTTP_USER_AGENT'])?$_SERVER['HTTP_USER_AGENT']:'');
        if ($this->editor_token) {
            $boundary->generatePostFields('editor_token', $this->editor_token);
        }

        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, 'http' . ((int)Configuration::getInstance()->get('port')===443?'s':''). '://'.Configuration::getInstance()->get('host').':'.Configuration::getInstance()->get('port'));
        curl_setopt($ch, CURLOPT_HEADER, 0);
        curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, 20);
        curl_setopt($ch, CURLOPT_TIMEOUT, 300);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $boundary->getContent());
        curl_setopt($ch, CURLOPT_HTTPHEADER, array(
            'Cache-Control: no-cache',
            'Content-Type: multipart/form-data; boundary=' . $boundary->getBoundary()
        ));
        if ((int)Configuration::getInstance()->get('port') === 443) {
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, true);
            curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 2);
            if (Configuration::getInstance()->get('dl_certificates') === true) {
                curl_setopt($ch, CURLOPT_CAINFO, Certificates::getPath());
            }
        }

        $time_start = microtime(true);
        $translated_content = curl_exec($ch);
        Debug::timing('Curl translation request took %s', $time_start);
        $response_code = curl_getinfo($ch, CURLINFO_HTTP_CODE);

        Debug::log('Translated content: ' . $translated_content, 5);

        if (!$translated_content || $response_code !== 200) {
            // Failed to translate, redirect visitor to the non translated page
            $response->clearContent();
            $non_translated_url = $request->getNonTranslatedUrl();
            Debug::log('Failed to translate, response code '.$response_code.', error: ' . curl_error($ch) . ', message: ' . $translated_content . ', redirect to ' . $non_translated_url);
            $response->setRedirect($non_translated_url, 307);
            $response->end();
        }

        curl_close($ch);


        $result = json_decode($translated_content);
        if (!$result) {
            // Failed to decode content, redirect visitor to the non translated page
            $response->clearContent();
            $non_translated_url = $request->getNonTranslatedUrl();
            Debug::log('Failed to decode translated content, redirect to ' . $non_translated_url);
            $response->setRedirect($non_translated_url, 307);
            $response->end();
        }

        Debug::log('Translation decoded ' . print_r($result, true), 3);

        if (isset($result->url_translations)) {
            Defer::getInstance()->defer(function() use ($result) {
                $new_urls = $result->url_translations;
                $new_urls = get_object_vars($new_urls);
                Database::getInstance()->saveUrls((array)$new_urls);
            });
        }

        if (isset($result->urls_untranslated)) {
            Defer::getInstance()->defer(function() use ($result) {
                Database::getInstance()->removeUrls((array)$result->urls_untranslated);
            });
        }

        if (isset($result->redirect)) {
            Debug::log('Translation redirect to ' . $result->redirect);
            $response->clearContent();
            $response->setRedirect($result->redirect . $request->getQuery(true), 301);
            $response->end();
        }

        if (isset($result->content_type)) {
            $response->setContentType($result->content_type);
        }

        $response->setContent($result->content);
        $response->setResponseCode(200, false);
    }
}
